@@ -15,22 +15,12 @@
 ***                                                                     ***
 **************************************************************************/
 
-
-
-
-
-
-
-/*
- * osplibversion.h - OSP Toolkit version
- */
-
+/* osplibversion.h - OSP Toolkit version */
 #ifndef _OSPLIBVERSION_H
 #define _OSPLIBVERSION_H
 
-#define OSP_CLIENT_TOOLKIT_VERSION_MAJOR	3
-#define OSP_CLIENT_TOOLKIT_VERSION_MINOR	4
-#define OSP_CLIENT_TOOLKIT_VERSION_BUGFIX	2
-
-#endif
+#define OSP_CLIENT_TOOLKIT_VERSION_MAJOR    4
+#define OSP_CLIENT_TOOLKIT_VERSION_MINOR    13
+#define OSP_CLIENT_TOOLKIT_VERSION_BUGFIX   0
 
+#endif /* _OSPLIBVERSION_H */
