@@ -15,15 +15,7 @@
 ***                                                                     ***
 **************************************************************************/
 
-
-
-
-
-
-
-/*
- * ospossys.h - OS dependent system macros.
- */
+/* ospossys.h - OS dependent system macros. */
 #ifndef _OSPOSSYS_H
 #define _OSPOSSYS_H
 
@@ -52,7 +44,7 @@
 
 #define OSPM_MEMSET(p,c,z) (void)memset((void *)p,c,z)
 
-#define OSPM_MEMCMP(p1,p2,z) memcmp(p1,p2,z) 
+#define OSPM_MEMCMP(p1,p2,z) memcmp(p1,p2,z)
 
 #define OSPM_MEMMOVE(p,s,z) memmove(p,s,z)
 
@@ -74,7 +66,7 @@
 #define OSPM_THR_SELF() pthread_self()
 
 #define OSPM_THR_JOIN(t,p) pthread_join(t,p)
-    
+
 #define OSPM_CREATE_THREAD(t,a,f,p,e) { \
     e = pthread_create(&t, a, f, p); \
     OSPM_DBG(e,("%s failed. %s\n", "pthread_create", strerror(errno))); \
@@ -146,8 +138,7 @@
 }
 #endif /* POSIX THREADS */
 
-
-#ifdef  _WIN32 
+#ifdef  _WIN32
 #ifndef _POSIX_THREADS
 /* MS Threads */
 #define OSPM_THR_SELF() GetCurrentThreadID()
@@ -160,7 +151,7 @@
 }
 
 /* currently unused in Win32 Threads */
-#define OSPM_THRATTR_INIT(a,e) a = 0, e = OSPC_ERR_NO_ERROR; 
+#define OSPM_THRATTR_INIT(a,e) a = 0, e = OSPC_ERR_NO_ERROR;
 #define OSPM_THRATTR_DESTROY(a) a = 0;
 #define OSPM_SETDETACHED_STATE(a,e) a = a, e = OSPC_ERR_NO_ERROR;
 
@@ -245,9 +236,9 @@
  * =============================================
  */
 
-/* -----------------------------*/
-/* WIN32 Winsock Macros         */
-/* -----------------------------*/
+/*
+ * WIN32 Winsock Macros
+ */
 #ifdef _WIN32
 
 #define OSPM_INITWINSOCK(e) { \
@@ -279,7 +270,7 @@
     if ((pHost = gethostbyname((const char *)h)) == (struct hostent *)NULL) \
     { \
         e = GetLastError(); \
-        OSPM_DBG(e,("%s failed for %s. \n", "gethostbyname", h)); \
+        OSPM_DBG(e,("%s failed for %s.\n", "gethostbyname", h)); \
         ip = 0; \
     } \
     else \
@@ -358,9 +349,9 @@
 }
 #else
 
-/* -----------------------------*/
-/* UNIX Sockets Macros          */
-/* -----------------------------*/
+/*
+ * UNIX Sockets Macros
+ */
 #define OSPM_INITWINSOCK(e)      { }
 
 #define OSPM_CLEANUPWINSOCK()    { }
@@ -484,14 +475,14 @@
 }
 #endif
 
-/* ----------------------------------*/
-/* Common Winsock/Sockets Functions  */
-/* ----------------------------------*/
-const char* OSPM_INET_NTOA(OSPTIPADDR ip, char* buf, socklen_t len);
+/*
+ * Common Winsock/Sockets Functions
+ */
+const char *OSPM_INET_NTOA(OSPTIPADDR ip, char *buf, socklen_t len);
 
-/* -------------------------------*/
-/* Common Winsock/Sockets Macros  */
-/* -------------------------------*/
+/*
+ * Common Winsock/Sockets Macros
+ */
 
 #define OSPM_DISABLE_NAGLE(s,e) { \
     int flag = 1; \
@@ -540,7 +531,7 @@ const char* OSPM_INET_NTOA(OSPTIPADDR ip, char* buf, socklen_t len);
 #define OSPM_STRNCMP(s1,s2,n)       strncmp((s1), (s2), (n))
 #define OSPM_STRLEN(s)              ((s != OSPC_OSNULL)? strlen(s) : 0)
 #define OSPM_STRNCAT(s1,s2,n)       strncat((s1), (s2), (n))
-#define OSPM_STRNCPY(s1,s2,n)       strncpy((char *)(s1), (const char *)(s2), (n))
+#define OSPM_STRNCPY(s1,s2,n);      { strncpy((char *)(s1), (const char *)(s2), (n)); (s1)[n - 1] = '\0'; }
 #define OSPM_STRNCASECMP(s1,s2,n)   strncasecmp((s1), (s2), (n))
 #define OSPM_STRTOUL(s1,a1,b)       strtoul((s1), (a1), (b))
 #define OSPM_STRSTR(s1,s2)          strstr((s1),(s2))
@@ -583,7 +574,7 @@ const char* OSPM_INET_NTOA(OSPTIPADDR ip, char* buf, socklen_t len);
     flag = _isnan(num); \
     }
 
-#define OSPM_ACCESS 	_access
+#define OSPM_ACCESS _access
 
 #else
 
@@ -603,7 +594,7 @@ const char* OSPM_INET_NTOA(OSPTIPADDR ip, char* buf, socklen_t len);
     flag = isnan(num); \
     }
 
-#define OSPM_ACCESS 	access
+#define OSPM_ACCESS access
 
 #endif
 
@@ -626,6 +617,4 @@ const char* OSPM_INET_NTOA(OSPTIPADDR ip, char* buf, socklen_t len);
 /* 'uses' the argument */
 #define OSPM_ARGUSED(x) (x=x)
 
-
-#endif
-
+#endif /* _OSPOSSYS_H */
