@@ -15,12 +15,6 @@
 ***                                                                     ***
 **************************************************************************/
 
-
-
-
-
-
-
 /*osptnprobe.c
     Summary:        Functions that probe a list of IP addresses and
                     return the response time value for each system.
@@ -37,9 +31,9 @@
         each server is captured and returned to the caller.
 
 
-        To call OSPPTNProbe, fill in the ospmipaddr field of an array of OSPT_TN_PROBE
+        To call OSPPTNProbe, fill in the IpAddr field of an array of OSPT_TN_PROBE
         structures and indicating the size of the array. The function will
-        return by filling in the ospmTime field for each element with the
+        return by filling in the Time field for each element with the
         number of milliseconds the system took to respond to a message sent
         to its echo/udp service.
 
@@ -94,45 +88,36 @@
 #include <stdio.h>
 #endif
 
-/*-----------------------------------------------------------------------*/
 /* private header file stuff */
 
 /* different status values */
-enum socket_stats{
-             OSPE_PRINIT,   /*  0  initialized */
-             OSPE_PRCONN,   /*  1  connected */
-             OSPE_PRSENT,   /*  2  request sent */
-             OSPE_PRREAD,   /*  3  reply received */
-             OSPE_PRDONE    /*  4  probe complete */
+enum socket_stats {
+    OSPE_PRINIT,    /*  0  initialized */
+    OSPE_PRCONN,    /*  1  connected */
+    OSPE_PRSENT,    /*  2  request sent */
+    OSPE_PRREAD,    /*  3  reply received */
+    OSPE_PRDONE     /*  4  probe complete */
 };
 
 /* miscellaneous constants */
 
-#define OSPC_TN_UDP_ECHOPORT 7      /* UDP echo port is 7 */
+#define OSPC_TN_UDP_ECHOPORT    7   /* UDP echo port is 7 */
 
 /* private globals - for multithreading, these MUST be read-only */
 
 static char tnBuffer[] = "test message";
 
-
-
-/*-----------------------------------------------------------------------*/
 /* OSPPTNProbe - probe systems and return response times */
-int
-OSPPTNProbe(            /*0 - normal; < 0 - error code  */
+int OSPPTNProbe(                /*0 - normal; < 0 - error code  */
     OSPT_TN_PROBE *pProbeList,  /* list to probe */
-    unsigned  uNumHosts,        /* number of hosts to check */
-    unsigned  uMaxWait          /* maximum wait in milliseconds */
-)
+    unsigned uNumHosts,         /* number of hosts to check */
+    unsigned uMaxWait)          /* maximum wait in milliseconds */
 {
+    fd_set fdSocketSet; /* set of sockets for testing */
+    int nMaxFd = 0, nMinFd = 0;
+    int uErr = OSPC_ERR_TNPROBE_ERROR;
 
-    fd_set    fdSocketSet;         /* set of sockets for testing */
-    int       nMaxFd = 0, 
-              nMinFd = 0;
-    int       uErr   = OSPC_ERR_TNPROBE_ERROR;
-
-    do 
-    {    /* Break out of loop on error */
+    do {    /* Break out of loop on error */
         /*
          * Nothing real fancy here, we initialize a socket for each host
          * (and set up the socket set), do the actual probes on the sockets,
@@ -145,44 +130,35 @@ OSPPTNProbe(            /*0 - normal; < 0 - error code  */
          */
 
         /* Step 1: Prepare the sockets for testing */
-        if ((nMaxFd = OSPPTNProbeInit(pProbeList, &uNumHosts, 
-            &fdSocketSet, &nMinFd))== -1)
-        {
+        if ((nMaxFd = OSPPTNProbeInit(pProbeList, &uNumHosts, &fdSocketSet, &nMinFd)) == -1) {
             break;
         }
 
         /* Step 2: Do the probes */
-        OSPPTNProbeEcho(&fdSocketSet, pProbeList, 
-            uNumHosts, uMaxWait, nMaxFd, nMinFd);
+        OSPPTNProbeEcho(&fdSocketSet, pProbeList, uNumHosts, uMaxWait, nMaxFd, nMinFd);
 
         uErr = OSPC_ERR_NO_ERROR;
 
-    } while (0);    
+    } while (0);
 
     /* Step 3: Clean up the Sockets */
     OSPPTNProbeCleanup(pProbeList, uNumHosts);
 
-    return(uErr);
-
+    return uErr;
 }
 
-
-/*-----------------------------------------------------------------------*/
 /* OSPPTNProbeInit - set up the sockets for probing */
-
-int                             /* returns maxFD (< 0 on error) */
-OSPPTNProbeInit(
+int OSPPTNProbeInit(            /* returns maxFD (< 0 on error) */
     OSPT_TN_PROBE *pProbeList,  /* list to initialize */
     unsigned *lpNumHosts,       /* number of hosts */
-    fd_set   *pSocketSet,       /* socket set */
-    int      *nMinFd            /* Min fdSocket val */
-)
+    fd_set *pSocketSet,         /* socket set */
+    int *nMinFd)                /* Min fdSocket val */
 {
-    int      fdSocket;              /* single socket */
-    register unsigned uCnt;         /* simple counter */
-    int      nMaxFd;                /* max fdSocket value */
-    int      errorcode = 0;
-    int      one = 1;
+    int fdSocket;               /* single socket */
+    register unsigned uCnt;     /* simple counter */
+    int nMaxFd;                 /* max fdSocket value */
+    int errorcode = 0;
+    int one = 1;
 
     /*
      * This function tries to set up things as much as possible prior
@@ -192,10 +168,10 @@ OSPPTNProbeInit(
      * opened, then it will stay there and we'll return an error.
      */
 
-    nMaxFd = -1;                     /* so far, no error */
+    nMaxFd = -1;                /* so far, no error */
     *nMinFd = 0x0fffffff;
 
-    /* ZERO OUT THE SOCKET SET 
+    /* ZERO OUT THE SOCKET SET
      */
 
     FD_ZERO(pSocketSet);
@@ -217,8 +193,7 @@ OSPPTNProbeInit(
      */
 
     /* iterate through the list of hosts to try */
-    for ( uCnt = 0; uCnt < *lpNumHosts; uCnt++)
-    {
+    for (uCnt = 0; uCnt < *lpNumHosts; uCnt++) {
 
         /*
          * initialize the status value - note that we must go through the entire
@@ -227,89 +202,72 @@ OSPPTNProbeInit(
          * the for loop.
          */
 
-        pProbeList[uCnt].ospmPrStatus = OSPE_PRINIT;
+        pProbeList[uCnt].Status = OSPE_PRINIT;
 
         /* open a socket to each remote host */
-        fdSocket = OSPPTNProbeConnect(pProbeList[uCnt].ospmipaddr);
+        fdSocket = OSPPTNProbeConnect(pProbeList[uCnt].IpAddr);
 
-        pProbeList[uCnt].ospmSocket = fdSocket;
+        pProbeList[uCnt].Socket = fdSocket;
 
-        if (fdSocket >= 0) /* negative socket is an error */
-        {
+        if (fdSocket >= 0) {    /* negative socket is an error */
             /* if no errors, update the status to connected */
-            pProbeList[uCnt].ospmPrStatus = OSPE_PRCONN;
+            pProbeList[uCnt].Status = OSPE_PRCONN;
 
             /* remember the socket */
             OSPM_BLOCKIO(fdSocket, one, errorcode);
-            if(errorcode == 0)
-            {
+            if (errorcode == 0) {
                 /* add it to select list */
-                FD_SET((unsigned)fdSocket, pSocketSet);
+                FD_SET((unsigned) fdSocket, pSocketSet);
 
                 /* and update the maxFd variable if needed */
-                if (fdSocket > nMaxFd)
-                {
+                if (fdSocket > nMaxFd) {
                     nMaxFd = fdSocket;
                 }
-                if (fdSocket < *nMinFd)
-                {
+                if (fdSocket < *nMinFd) {
                     *nMinFd = fdSocket;
                 }
             }
         }
     }
 
-    return(nMaxFd);
+    return nMaxFd;
 }
 
-
 /* OSPPTNProbeConnect - connect socket to specific address for probes */
-
-int                     /* returns socket descriptor, < 0 == error */
-OSPPTNProbeConnect(
-    OSPTIPADDR ipAddr   /* remote address to connect */
-)
+int OSPPTNProbeConnect( /* returns socket descriptor, < 0 == error */
+    OSPTIPADDR ipAddr)  /* remote address to connect */
 {
-    int                 fdSocket;    /* socket file descriptor */
-    int                 uErr    = OSPC_ERR_NO_ERROR;
-    struct timeval      timeout;
-    OSPTSSLSESSION      *sslsess = OSPC_OSNULL;
+    int fdSocket;       /* socket file descriptor */
+    int uErr = OSPC_ERR_NO_ERROR;
+    struct timeval timeout;
+    OSPTSSLSESSION *sslsess = OSPC_OSNULL;
 
     /* allocate a socket */
     OSPM_UDP_SOCKET(fdSocket, uErr);
 
-    timeout.tv_sec  = OSPC_DEFAULT_PROBE_CONNECT / 1000;
+    timeout.tv_sec = OSPC_DEFAULT_PROBE_CONNECT / 1000;
     timeout.tv_usec = OSPC_DEFAULT_PROBE_CONNECT % 1000 * 1000;
 
-    if ((fdSocket >= 0) && uErr == 0)
-    {
+    if ((fdSocket >= 0) && uErr == 0) {
 
         /* connect the socket */
+        uErr = OSPPSockConnect(&fdSocket, OSPC_DEFAULT_BLOCKING_FLAG, ipAddr, htons(OSPC_TN_UDP_ECHOPORT), &timeout, &sslsess);
 
-        uErr = OSPPSockConnect(&fdSocket, OSPC_DEFAULT_BLOCKING_FLAG, ipAddr, htons(OSPC_TN_UDP_ECHOPORT), 
-            &timeout, &sslsess);
-
-        if (uErr)
-        {
+        if (uErr) {
             fdSocket = -1;
         }
     }
 
-    return(fdSocket);
+    return fdSocket;
 }
 
-
-/*-----------------------------------------------------------------------*/
 /* OSPPTNProbeCleanup - free resources, etc. after probing */
-
-void
-OSPPTNProbeCleanup(
+void OSPPTNProbeCleanup(
     OSPT_TN_PROBE *pProbeList,  /* list to cleanup */
-    unsigned  uNumHosts         /* number of hosts */
-)
+    unsigned uNumHosts)         /* number of hosts */
 {
-    register unsigned uCnt;                  /* simple counter */
-    int    errorcode = OSPC_ERR_NO_ERROR;
+    register unsigned uCnt; /* simple counter */
+    int errcode = OSPC_ERR_NO_ERROR;
 
     /*
      * Two things happening here: First, we close all the sockets
@@ -318,56 +276,47 @@ OSPPTNProbeCleanup(
      * host to infinity.
      */
 
-    for ( uCnt=0; uCnt < uNumHosts; uCnt++ )
-    {
+    for (uCnt = 0; uCnt < uNumHosts; uCnt++) {
         /* if we were able to open a socket, close it */
-        if (pProbeList[uCnt].ospmPrStatus > OSPE_PRINIT)
-        {
-            OSPM_CLOSE(pProbeList[uCnt].ospmSocket, errorcode);
+        if (pProbeList[uCnt].Status > OSPE_PRINIT) {
+            OSPM_CLOSE(pProbeList[uCnt].Socket, errcode);
         }
 
         /* if an error, set the response time to infinite */
-        if (pProbeList[uCnt].ospmPrStatus < OSPE_PRDONE)
-        {
-            pProbeList[uCnt].ospmTime = (unsigned long)(-1);
+        if (pProbeList[uCnt].Status < OSPE_PRDONE) {
+            pProbeList[uCnt].Time = (unsigned long)(-1);
         }
     }
 }
 
-
-/*-----------------------------------------------------------------------*/
 /* OSPPTNProbeEcho - actually do the echo and wait for replies */
-
-void
-OSPPTNProbeEcho(
-    fd_set   *pSockets,             /* sockets to probe */
-    OSPT_TN_PROBE *pProbeList,      /* place to store results */
-    unsigned  uNumHosts,            /* number of hosts to probe */
-    unsigned  uMaxWait,             /* max ms to wait */
-    int       nMaxFd,               /* max fd number for sockets */
-    int       nMinFd            /* min fd number for sockets */
-)
+void OSPPTNProbeEcho(
+    fd_set *pSockets,           /* sockets to probe */
+    OSPT_TN_PROBE *pProbeList,  /* place to store results */
+    unsigned uNumHosts,         /* number of hosts to probe */
+    unsigned uMaxWait,          /* max ms to wait */
+    int nMaxFd,                 /* max fd number for sockets */
+    int nMinFd)                 /* min fd number for sockets */
 {
-    fd_set    fdReadSet;                /* current working set */
-    int       fdSocket          = 0;    /* current socket */
-    unsigned  uHostsLeft        = 0;    /* hosts still pending */
-    unsigned  uTimeLeft         = 0;    /* time remaining */
-    register unsigned  uHost    = 0;    /* element number in pProbeList */
-    unsigned  uSent             = 0;    /* bytes sent */
-    int       nRecv             = 0;    /* bytes received */
-    register int       nCnt     = 0;    /* simple counter */
-    int       nRetVal           = 0;    /* return value from select */
-    unsigned long uTime1        = 0;    /* temp value for time calculations */
-    unsigned long uTime2        = 0;    /* temp value for time calculations */
-    struct timeval timeout;             /* timeout value for select */
-    int       uErr              = OSPC_ERR_NO_ERROR;   /* Error value */
-    char      recvbuf[100];
+    fd_set fdReadSet;               /* current working set */
+    int fdSocket = 0;               /* current socket */
+    unsigned uHostsLeft = 0;        /* hosts still pending */
+    unsigned uTimeLeft = 0;         /* time remaining */
+    register unsigned uHost = 0;    /* element number in pProbeList */
+    unsigned uSent = 0;             /* bytes sent */
+    int nRecv = 0;                  /* bytes received */
+    register int nCnt = 0;          /* simple counter */
+    int nRetVal = 0;                /* return value from select */
+    unsigned long uTime1 = 0;       /* temp value for time calculations */
+    unsigned long uTime2 = 0;       /* temp value for time calculations */
+    struct timeval timeout;         /* timeout value for select */
+    int uErr = OSPC_ERR_NO_ERROR;   /* Error value */
+    char recvbuf[100];
 
     OSPM_MEMSET(recvbuf, 0, sizeof(recvbuf));
     OSPM_MEMSET(&timeout, 0, sizeof(struct timeval));
 
-    do 
-    {    /* Break out of loop on error */
+    do {                        /* Break out of loop on error */
         /*
          * This function actually sends the test datagram and waits
          * for a response. The general steps are
@@ -382,31 +331,23 @@ OSPPTNProbeEcho(
         uHostsLeft = uNumHosts;
 
         /* start the echo on each socket */
-        for (uHost=0; uHost<uNumHosts; uHost++)
-        {
-            if(pProbeList[uHost].ospmSocket >= 0)
-            {
+        for (uHost = 0; uHost < uNumHosts; uHost++) {
+            if (pProbeList[uHost].Socket >= 0) {
                 /* transmit the datagram */
-                OSPM_SEND(pProbeList[uHost].ospmSocket, uSent, tnBuffer, 
-                    sizeof(tnBuffer), uErr);
-                if (uSent != sizeof(tnBuffer))
-                {
+                OSPM_SEND(pProbeList[uHost].Socket, uSent, tnBuffer, sizeof(tnBuffer), uErr);
+                if (uSent != sizeof(tnBuffer)) {
                     /* if the send didn't succeed, ... */
-                    uHostsLeft--;     /* there's one less host that will respond */
-                }
-                else
-                {
-                    pProbeList[uHost].ospmPrStatus = OSPE_PRSENT;
+                    uHostsLeft--;   /* there's one less host that will respond */
+                } else {
+                    pProbeList[uHost].Status = OSPE_PRSENT;
                 }
 
                 /* remember the current time */
-                pProbeList[uHost].ospmTime = OSPPTNProbeTimerMS();
+                pProbeList[uHost].Time = OSPPTNProbeTimerMS();
 
                 /* reset uSent */
                 uSent = 0;
-            }
-            else
-            {
+            } else {
                 /* invalid socket; decrement number of hosts that will respond */
                 uHostsLeft--;
             }
@@ -432,10 +373,9 @@ OSPPTNProbeEcho(
          */
 
         uTimeLeft = uMaxWait;           /* to start out, we've got the full time */
-        uTime1 = OSPPTNProbeTimerMS();        /* remember starting time */
+        uTime1 = OSPPTNProbeTimerMS();  /* remember starting time */
 
-        while (uHostsLeft > 0)
-        {
+        while (uHostsLeft > 0) {
             /* make a working copy of our socket set */
             memcpy(&fdReadSet, pSockets, sizeof(fdReadSet));
 
@@ -444,18 +384,17 @@ OSPPTNProbeEcho(
             timeout.tv_usec = (uTimeLeft % 1000) * 1000;
 
             /* call select and wait for replies */
-            nRetVal = select( nMaxFd+1,              /* Higest FD to test for */
-                &fdReadSet,            /* set for reading */
-                (fd_set *)0,           /* set for writing */
-                (fd_set *)0,           /* set for exceptions */
-                &timeout );            /* time to wait */
+            nRetVal = select(nMaxFd + 1,    /* Higest FD to test for */
+                &fdReadSet,                 /* set for reading */
+                (fd_set *)0,                /* set for writing */
+                (fd_set *)0,                /* set for exceptions */
+                &timeout);                  /* time to wait */
 
-            /* CHECK FOR ERRORS/TIMEOUT 
-            */
-            if (nRetVal <= 0) 
-            {
+            /* CHECK FOR ERRORS/TIMEOUT
+             */
+            if (nRetVal <= 0) {
                 /*
-                 * Time ran out or Error Occurred; 
+                 * Time ran out or Error Occurred;
                  */
                 break;
             }
@@ -464,54 +403,39 @@ OSPPTNProbeEcho(
             uTime2 = OSPPTNProbeTimerMS();
 
             /* check to see if timer has rolled over and make adjustment */
-            if (uTime2 < uTime1)
-            {
+            if (uTime2 < uTime1) {
                 uTime2 = (OSPC_TNPROBE_MAXTIMER - uTime1) + uTime2;
             }
 
             /* Now see who replied */
-            for ( nCnt=nRetVal, fdSocket=nMinFd;
-                ((nCnt > 0) && (fdSocket <= nMaxFd));
-                ++fdSocket)
-            {
-                if (FD_ISSET(fdSocket, &fdReadSet))
-                {
+            for (nCnt = nRetVal, fdSocket = nMinFd; ((nCnt > 0) && (fdSocket <= nMaxFd)); ++fdSocket) {
+                if (FD_ISSET(fdSocket, &fdReadSet)) {
                     /* which host responded? */
-                    for (uHost=0; uHost<uNumHosts; uHost++)
-                    {
-                        if (pProbeList[uHost].ospmSocket == (fdSocket))
-                        {
+                    for (uHost = 0; uHost < uNumHosts; uHost++) {
+                        if (pProbeList[uHost].Socket == (fdSocket)) {
                             break;
                         }
                     }
 
                     /* make sure we found a host */
-                    if (uHost < uNumHosts)
-                    {
-                        if (!(pProbeList[uHost].ospmPrStatus == OSPE_PRSENT)) 
-                        {
+                    if (uHost < uNumHosts) {
+                        if (!(pProbeList[uHost].Status == OSPE_PRSENT)) {
                             break;
                         }
 
-
                         /* receive the datagram */
                         nRecv = recv(fdSocket, recvbuf, sizeof(recvbuf), 0);
-                        if (nRecv <= 0)  
-                        {
+                        if (nRecv <= 0) {
                             break;
-                        }
-                        else if(memcmp(tnBuffer, recvbuf, nRecv) != 0)
-                        {
+                        } else if (memcmp(tnBuffer, recvbuf, nRecv) != 0) {
                             break;
                         }
 
                         /* calculate how long it took */
-                        pProbeList[uHost].ospmTime =
-                            uTime2 - pProbeList[uHost].ospmTime;
-
+                        pProbeList[uHost].Time = uTime2 - pProbeList[uHost].Time;
 
                         /* update the status of the current socket */
-                        pProbeList[uHost].ospmPrStatus = OSPE_PRDONE;
+                        pProbeList[uHost].Status = OSPE_PRDONE;
                     }
 
                     /*
@@ -520,15 +444,14 @@ OSPPTNProbeEcho(
                      * left to check as well as the number of hosts on which
                      * we're still waiting.
                      */
-                    FD_CLR((unsigned)fdSocket, pSockets);
+                    FD_CLR((unsigned) fdSocket, pSockets);
                     nCnt--;
                     uHostsLeft--;
                 }
             }
 
             /* update the time left */
-            if ((uTime2 - uTime1) < uTimeLeft)
-            {
+            if ((uTime2 - uTime1) < uTimeLeft) {
                 /*
                  * Note that we have to check to make sure the delta time is
                  * greater than the time left; we can't simply subtract the
@@ -536,9 +459,7 @@ OSPPTNProbeEcho(
                  */
                 uTimeLeft -= (uTime2 - uTime1);
                 uTime1 = uTime2;
-            }
-            else
-            {
+            } else {
                 /*
                  * In this case, our allotted time has expired. This is probably
                  * pretty unlikely, as we'd expect most expirations to happen
@@ -547,25 +468,18 @@ OSPPTNProbeEcho(
                  */
                 break;
             }
-
         }
-
     } while (0);
-
-    return;
 }
 
-/*-----------------------------------------------------------------------*/
 /* OSPPTNProbeTimerMS - current time in milliseconds  */
-
-unsigned long                       /* returns current time in ms */
-OSPPTNProbeTimerMS(void)
+unsigned long OSPPTNProbeTimerMS(void)  /* returns current time in ms */
 {
-    unsigned long   millisecs   = 0;
-    int             errcode     = 0;
+    unsigned long millisecs = 0;
+    int errcode = 0;
 
-#ifndef _WIN32 /* UNIX */
-    struct timeb   timenow;
+#ifndef _WIN32  /* UNIX */
+    struct timeb timenow;
 
     OSPM_MEMSET(&timenow, 0, sizeof(struct timeb));
     errcode = ftime(&timenow);
@@ -577,49 +491,38 @@ OSPPTNProbeTimerMS(void)
     _ftime(&timenow);
 #endif
 
-    if(errcode != -1)
-    {
+    if (errcode != -1) {
         millisecs = ((timenow.time % OSPC_TNPROBE_TIMERMOD) * OSPC_TNPROBE_TIMERMULT) + timenow.millitm;
     }
 
-    return(millisecs);
+    return millisecs;
 }
 
-void
-OSPPTNProbePruneList(
-    OSPTLIST        *ospvDests,
-    OSPT_TN_PROBE   *ospvProbes,
-    unsigned        ospvDelayLimit,
-    unsigned        *ospvNumDests)
+void OSPPTNProbePruneList(
+    OSPTLIST *ospvDests,
+    OSPT_TN_PROBE *ospvProbes,
+    unsigned ospvDelayLimit,
+    unsigned *ospvNumDests)
 {
 
-    OSPT_TN_PROBE   *tmpprobelist   = ospvProbes;
-    unsigned        probecnt        = 0,
-                    deccnt          = 0,
-                    numleft         = *ospvNumDests;
-    OSPTDEST        *dest           = OSPC_OSNULL;
-    OSPTSVCPT       *svcpt          = OSPC_OSNULL;
+    OSPT_TN_PROBE *tmpprobelist = ospvProbes;
+    unsigned probecnt = 0, deccnt = 0, numleft = *ospvNumDests;
+    OSPT_DEST *dest = OSPC_OSNULL;
+    OSPTSVCPT *svcpt = OSPC_OSNULL;
 
-    while(probecnt < *ospvNumDests)
-    {
-        if(tmpprobelist->ospmTime > ospvDelayLimit)
-        {
+    while (probecnt < *ospvNumDests) {
+        if (tmpprobelist->Time > ospvDelayLimit) {
 
-            /* find specific node in destlist that matches ipaddr 
+            /* find specific node in destlist that matches ipaddr
              * in probelist and remove it
              */
-            for(dest = (OSPTDEST *)OSPPListFirst(ospvDests);
-                dest != OSPC_OSNULL;
-                dest = (OSPTDEST *)OSPPListNext(ospvDests, dest))
-            {
+            for (dest = (OSPT_DEST *)OSPPListFirst(ospvDests); dest != OSPC_OSNULL; dest = (OSPT_DEST *)OSPPListNext(ospvDests, dest)) {
 
-                (void)OSPPCommParseSvcPt((const char *)OSPPDestGetAddr(dest), &svcpt, 0);
+                OSPPCommParseSvcPt(OSPPDestGetAddr(dest), &svcpt, 0);
 
-                if (svcpt != (OSPTSVCPT *)OSPC_OSNULL)
-                {
+                if (svcpt != OSPC_OSNULL) {
 
-                    if(svcpt->IpAddr == tmpprobelist->ospmipaddr)
-                    {
+                    if (svcpt->IpAddr == tmpprobelist->IpAddr) {
                         OSPPListRemoveSpecificItem(ospvDests, dest);
 
                         if (svcpt->HostName)
@@ -648,14 +551,11 @@ OSPPTNProbePruneList(
             deccnt = probecnt;
 
             /* now remove that node from probelist */
-            while(deccnt < numleft)
-            {
+            while (deccnt < numleft) {
                 ospvProbes[deccnt] = ospvProbes[deccnt + 1];
                 deccnt++;
             }
-        }
-        else
-        {
+        } else {
             /* move probe pointer only if copy has not been done */
             tmpprobelist++;
         }
@@ -665,54 +565,39 @@ OSPPTNProbePruneList(
 
     /* reset NumDests */
     *ospvNumDests = numleft;
-
-    return;
 }
 
-int 
-OSPPTNProbeCompare( 
-    const void *probeptr1, 
-    const void *probeptr2
-)
+int OSPPTNProbeCompare(
+    const void *probeptr1,
+    const void *probeptr2)
 {
-    return ((OSPT_TN_PROBE *)probeptr1)->ospmTime - ((OSPT_TN_PROBE *)probeptr2)->ospmTime;
+    return ((OSPT_TN_PROBE *)probeptr1)->Time - ((OSPT_TN_PROBE *)probeptr2)->Time;
 }
 
-void         
-OSPPTNProbeArrangeList(
-    OSPTLIST        *ospvDests,
-    OSPT_TN_PROBE   *ospvProbes,
-    unsigned        ospvNumDests
-)
+void OSPPTNProbeArrangeList(
+    OSPTLIST *ospvDests,
+    OSPT_TN_PROBE *ospvProbes,
+    unsigned ospvNumDests)
 {
-    OSPTLIST    newlist     = OSPC_OSNULL;
-    unsigned    probecnt    = 0;
-    OSPTDEST    *dest       = OSPC_OSNULL;
-    OSPTSVCPT   *svcpt      = OSPC_OSNULL;
+    OSPTLIST newlist = OSPC_OSNULL;
+    unsigned probecnt = 0;
+    OSPT_DEST *dest = OSPC_OSNULL;
+    OSPTSVCPT *svcpt = OSPC_OSNULL;
 
-    qsort((void *)ospvProbes, (size_t)ospvNumDests, 
-        sizeof(OSPT_TN_PROBE), OSPPTNProbeCompare);
+    qsort((void *)ospvProbes, (size_t)ospvNumDests, sizeof(OSPT_TN_PROBE), OSPPTNProbeCompare);
 
     OSPPListNew(&newlist);
 
-    for(probecnt = 0;
-        probecnt < ospvNumDests;
-        probecnt++)
-    {
+    for (probecnt = 0; probecnt < ospvNumDests; probecnt++) {
 
-        /* find specific node in destlist that matches ipaddr 
+        /* find specific node in destlist that matches ipaddr
          * in probelist, remove it and add to new list
          */
-        for(dest = (OSPTDEST *)OSPPListFirst(ospvDests);
-            dest != OSPC_OSNULL;
-            dest = (OSPTDEST *)OSPPListNext(ospvDests, dest))
-        {
+        for (dest = (OSPT_DEST *)OSPPListFirst(ospvDests); dest != OSPC_OSNULL; dest = (OSPT_DEST *)OSPPListNext(ospvDests, dest)) {
 
-            (void)OSPPCommParseSvcPt((const char *)OSPPDestGetAddr(dest), &svcpt, 0);
-            if (svcpt != (OSPTSVCPT *)OSPC_OSNULL)
-            {
-                if(svcpt->IpAddr == ospvProbes[probecnt].ospmipaddr)
-                {
+            OSPPCommParseSvcPt(OSPPDestGetAddr(dest), &svcpt, 0);
+            if (svcpt != OSPC_OSNULL) {
+                if (svcpt->IpAddr == ospvProbes[probecnt].IpAddr) {
                     OSPPListRemoveSpecificItem(ospvDests, dest);
                     OSPPListAppend(&newlist, dest);
                     dest = OSPC_OSNULL;
@@ -726,9 +611,7 @@ OSPPTNProbeArrangeList(
                     OSPM_FREE(svcpt);
 
                     break;
-                }
-                else
-                {
+                } else {
                     if (svcpt->HostName)
                         OSPM_FREE(svcpt->HostName);
 
@@ -737,12 +620,9 @@ OSPPTNProbeArrangeList(
 
                     OSPM_FREE(svcpt);
                 }
-            }    
+            }
         }
     }
 
     *ospvDests = newlist;
-
-    return;
 }
-
